@@ -66,7 +66,7 @@ new IotToLambda(scope: Construct, id: string, props: IotToLambdaProps);
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.|
+|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.|
 |lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|User provided props to override the default props for the Lambda function.|
 |iotTopicRuleProps?|[`iot.CfnTopicRuleProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iot.CfnTopicRuleProps.html)|User provided CfnTopicRuleProps to override the defaults|
 
@@ -138,7 +138,7 @@ class IotToLambda(
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param iot_topic_rule_props: User provided CfnTopicRuleProps to override the defaults. Default: - None
-        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
+        :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
 
         :access: public
@@ -183,7 +183,7 @@ class IotToLambdaProps:
     ) -> None:
         '''
         :param iot_topic_rule_props: User provided CfnTopicRuleProps to override the defaults. Default: - None
-        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
+        :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
 
         :summary: The properties for the IotToLambda class.
@@ -212,7 +212,7 @@ class IotToLambdaProps:
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
-        '''Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
+        '''Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error.
 
         :default: - None
         '''
